@@ -229,7 +229,7 @@ def pie_chart_keywords_terrorist(data):
 	
 
 def terrorist_hashtags_belonging(data):
-	temp = data[ data['hashtags_score']>0].reset_index(drop=True)
+	temp = data[ data['hashtag_score']>0].reset_index(drop=True)
 	# Draw plot
 	fig, ax = plt.subplots(figsize=(36,24), dpi= 80)
 	ax.vlines(x=temp.index, ymin=0, ymax=temp.hashtags_score, color='firebrick', alpha=0.7, linewidth=2)
@@ -246,7 +246,7 @@ def terrorist_hashtags_belonging(data):
 	plt.show()
 
 def pie_chart_hashtags_terrorist(data):
-	temp = data[data['hashtags_score']>0].reset_index(drop=True)  
+	temp = data[data['hashtag_score']>0].reset_index(drop=True)  
 	p=0
 	n=0
 	o=0
